<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-medias?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// M
	'medias_description' => 'Medienverwaltung in  SPIP',
	'medias_slogan' => 'Medienverwaltung in  SPIP',
];
